按semver规则, 取得最大版本号. 并且支持以版本编译信息作为二次判断条件. 最后以key=value的形式输出

代码仓库

  https://code.ppgame.com/JenkinsABS/tool-S3ObjVersion

可用客户端:

  AWS s3

  Tencent COS

  Minio

输出

  S3PKG_VERSION=1.0.3+15047.0004
